SysResult

Struct SysResult 

pub struct SysResult(/* private fields */);
Represents the results of a SafaOS syscall, either an ErrorStatus or an Ok usize value smaller than or equal to isize::MAX.

Implementations

Source

impl SysResult

pub const fn err(err: ErrorStatus) -> Self

Converts an err into a SysResult.

pub const fn into_result(self) -> Result<usize, ErrorStatus>

Turns a SysResult into result.

pub const fn try_from_result( result: Result<usize, ErrorStatus>, ) -> Result<Self, ()>

Attempts to convert a result into SysResult, returns an error if the value is Ok(x) and x is larger than isize::MAX

pub const fn ok(value: usize) -> Self

Converts an Ok value [value] into Self, it is expected to not be larger than isize::MAX or it panicks.

pub const fn try_ok(value: usize) -> Result<Self, ()>

Tries to convert an Ok value [value] into SysResult, return an error if the value is larger than isize::MAX.

pub const fn as_isize(&self) -> isize

Converts a SysResult into an isize, negative value is for an error, use Self::into_result instead.

pub const fn from_isize(isize: isize) -> Self

Converts an isize into SysResult

Safety

Perefectly safe as this type doesn’t guarantee the contained error value (negative value) is valid.