pub struct OpenOptions(/* private fields */);Expand description
Describes the options for opening a file or directory.
Implementations
Sourceimpl OpenOptions
impl OpenOptions
Sourcepub const CREATE_FILE: Self
pub const CREATE_FILE: Self
Create the file if it does not exist.
Sourcepub const CREATE_DIRECTORY: Self
pub const CREATE_DIRECTORY: Self
Create the directory if it does not exist. (doesn’t create parent directories)
Sourcepub const WRITE_TRUNCATE: Self
pub const WRITE_TRUNCATE: Self
Truncate the file to zero length if it already exists.
pub const fn from_bits(bits: u8) -> Self
pub const fn contains(self, other: Self) -> bool
pub const fn is_write(&self) -> bool
pub const fn is_write_truncate(&self) -> bool
pub const fn is_read(&self) -> bool
pub const fn create_file(&self) -> bool
pub const fn create_dir(&self) -> bool