#[repr(u32)]pub enum MouseEventKind {
Null = 0,
Change = 3,
}Variants
Null = 0
Change = 3
Represents a change in the mouse status, for now the mouse doesn’t report the exact event change because there could be multiple