pub struct MiceEvent {
pub kind: MouseEventKind,
pub buttons_status: MiceBtnStatus,
pub x_rel_change: i16,
pub y_rel_change: i16,
}Expand description
Describes a Mice change event
Fields
kind: MouseEventKindThe buttons status
x_rel_change: i16The X relative change, positive means right, negative means left
y_rel_change: i16The Y relative change, positive means up, negative means down, assuming the coordinate system has the bigger Y the more up, which isn’t true for most computer software so you have to invert the Y axis.
Implementations