MemMapFlags

Struct MemMapFlags 

pub struct MemMapFlags(/* private fields */);
Implementations

Source

impl MemMapFlags

pub const FIXED: Self

The given address is a just a hint unless specified with this flag

pub const WRITE: Self

Allows the memory to be written to, makes it RW, by default it is only R

pub const DISABLE_EXEC: Self

Don’t allow the memory to be executed

pub const MAP_RESOURCE: Self

The given Resource ID is a valid resource to map, by default the given resource ID is ignored and the memory is treated as not associated with anything

Source

impl MemMapFlags

pub fn from_bits_retaining(bits: u8) -> Self

pub fn contains(self, other: MemMapFlags) -> bool