PollEntry

Struct PollEntry 

pub struct PollEntry { /* private fields */ }
The layout of a single entry passed to crate::syscalls::SyscallTable::SysIOPoll.

Implementations

Source

impl PollEntry

pub const fn new(resource: u32, events: PollEvents) -> Self

pub const fn resource(&self) -> u32

Returns the resource ID associated with this poll entry.

pub const fn events(&self) -> PollEvents

Returns the events associated with this poll entry.

pub const fn returned_events(&self) -> PollEvents

Returns the events that were returned by the poll operation.

pub const fn returned_events_mut(&mut self) -> &mut PollEvents

Returns a mutable reference to the events that were returned by the poll operation.