PollEvents

Struct PollEvents 

pub struct PollEvents(/* private fields */);

Implementations

Source

impl PollEvents

pub const NONE: Self

Waiting for no events, ignored.

pub const DATA_AVAILABLE: Self

Waiting for data to be available to read.

pub const CAN_WRITE: Self

Waiting for the resource to be writable without blocking.

pub const DISCONNECTED: Self

The given resource is disconnected, usually is returned and not awaited for. reads may still be possible if there is data available.

pub const ALL: Self

Waiting for all events.

pub const fn contains(&self, other: Self) -> bool

pub const fn intersects(&self, other: Self) -> bool

pub const fn is_empty(&self) -> bool

pub const fn union(&self, other: Self) -> Self

pub const fn intersection(&self, other: Self) -> Self

pub const fn difference(&self, other: Self) -> Self