RawContextPriority

Enum RawContextPriority 

#[repr(u8)]
pub enum RawContextPriority { Default = 0, Low = 1, Medium = 2, High = 3, }

Variants



Default = 0

Default priority, used when no custom priority is specified, the behaviour is not clearly defined if you choose this priority, but it should be the default, currently the kernel will use the Medium priority if this was passed to the SysPSpawn syscall, later on it could inherit the priority of the parent process

Incase of the SysTSpawn syscall, the kernel will inherit the priority of the parent process



Low = 1



Medium = 2



High = 3