AbiStructures

Struct AbiStructures 

#[repr(C)]
pub struct AbiStructures { pub stdio: ProcessStdio, pub parent_process_pid: u32, pub available_cpus: u32, }
ABI structures are structures that are passed to processes by the parent process for now only stdio file descriptors are passed you get a pointer to them in the r8 register at _start (the 5th argument)

Fields

stdio: ProcessStdioparent_process_pid: u32

The PID of the parent process of this thread

available_cpus: u32

The number of available CPUs for this process (currently the number of available CPUs in the system)

Implementations

Source

impl AbiStructures

pub fn new(stdio: ProcessStdio, parent_pid: u32, available_cpus: u32) -> Self