RawTSpawnConfig

Struct RawTSpawnConfig 

pub struct RawTSpawnConfig {
    pub revision: u32,
    pub argument_ptr: *const (),
    pub priority: RawContextPriority,
    pub cpu: COption<u8>,
    pub custom_stack_size: OptZero<ShouldNotBeZero<usize>>,
    /* private fields */
}
configuration for the thread spawn syscall for now it takes only a single argument pointer which is a pointer to an optional argument, that pointer is going to be passed to the thread as the second argument

Fields

revision: u32

revision 1: added custom stack size

argument_ptr: *const ()priority: RawContextPrioritycpu: COption<u8>

The index of the CPU to append to, if it is None the kernel will choose one, use 0 for the boot CPU

custom_stack_size: OptZero<ShouldNotBeZero<usize>>

revision 1 and above

Implementations

Source

impl RawTSpawnConfig

pub const fn new_from_raw( argument_ptr: *const (), priority: RawContextPriority, cpu: COption<u8>, custom_stack_size: OptZero<ShouldNotBeZero<usize>>, ) -> Self

Creates a new thread spawn configuration with the latest revision from raw FFI values

pub fn new( argument_ptr: *const (), priority: RawContextPriority, cpu: Option<u8>, custom_stack_size: Option<NonZero<usize>>, ) -> Self

Create a new thread spawn configuration with the latest revision