SockCreateKind

Struct SockCreateKind 

pub struct SockCreateKind(/* private fields */);
Flags given to crate::syscalls::SyscallTable::SysSockCreate, Also contains information about the Socket Type, by default the Socket Type is SOCK_STREAM and blocking unless a flag was given

Implementations

Source

impl SockCreateKind

pub const SOCK_STREAM: Self

A stream socket, only allowed for local domain sockets.

pub const SOCK_SEQPACKET: Self

A SeqPacket Socket, unlike Stream Sockets which are the default for local sockets, this preserves messages boundaries

pub const SOCK_DGRAM: Self

A Datagram Socket, only allowed for network domain sockets, UDP by default and preserves messages boundaries.

pub const SOCK_NON_BLOCKING: Self

A Non Blocking Socket, anything that would normally block would return crate::errors::ErrorStatus::WouldBlock instead of blocking except for crate::syscalls::SyscallTable::SysSockConnect, this one is defined by POSIX as not blockable but it is way too hard to implement ._.

pub const fn contains(&self, other: Self) -> bool

returns true If self contains the flags other containsa

pub const fn from_bits_retaining(bits: u16) -> Self