SockMsgFlags

Struct SockMsgFlags 

pub struct SockMsgFlags(/* private fields */);
Flags for a message transmitted to and received from a socket.

Implementations

Source

impl SockMsgFlags

pub const NONE: Self

pub const DONT_WAIT: Self

Return an error if sending/receiving the message would block instead of blocking.

pub const PEEK: Self

For a receive operation, only read the message without removing it from the queue, so another receive operation would read the same exact message.

pub const fn contains(&self, other: Self) -> bool

Returns true If self contains the flags other containsa

pub const fn from_bits_retaining(bits: u32) -> Self

pub const fn into_bits(self) -> u32