pub struct MemMapFlags(/* private fields */);Expand description
Flags passed to crate::syscalls::SyscallTable::SysMemMap
Implementations
Sourceimpl MemMapFlags
impl MemMapFlags
Sourcepub const DISABLE_EXEC: Self
pub const DISABLE_EXEC: Self
Don’t allow the memory to be executed
Sourcepub const MAP_RESOURCE: Self
pub const MAP_RESOURCE: Self
The given Resource ID is a valid resource to map, by default the given resource ID is ignored and the memory is treated as not associated with anything
Sourceimpl MemMapFlags
impl MemMapFlags
pub fn from_bits_retaining(bits: u8) -> Self
pub fn contains(self, other: MemMapFlags) -> bool