#[repr(C)]pub struct RawMemMapConfig {
pub addr_hint: *const (),
pub page_count: usize,
pub guard_pages_count: usize,
pub resource_to_map: usize,
pub resource_off: isize,
}Expand description
Passed to crate::syscalls::SyscallTable::SysMemMap, to describe the address, the size, of the area to map to, and the resource it is associated with
Fields
addr_hint: *const ()Address hint can be null to indicate no hint
page_count: usizeThe amount of pages to map
guard_pages_count: usizeThe amount of unmapped guard pages before and after the area
resource_to_map: usizeThe ID of the associated Resource to map, ignored unless the flag MemMapFlags::MAP_RESOURCE was given
resource_off: isizeIf Mapping A Resource, Describes the offset to where the memory mapping