pub struct PollEntry { /* private fields */ }Expand description
The layout of a single entry passed to crate::syscalls::SyscallTable::SysIOPoll.
Implementations
Sourceimpl PollEntry
impl PollEntry
pub const fn new(resource: u32, events: PollEvents) -> Self
Sourcepub const fn events(&self) -> PollEvents
pub const fn events(&self) -> PollEvents
Returns the events associated with this poll entry.
Sourcepub const fn returned_events(&self) -> PollEvents
pub const fn returned_events(&self) -> PollEvents
Returns the events that were returned by the poll operation.
Sourcepub const fn returned_events_mut(&mut self) -> &mut PollEvents
pub const fn returned_events_mut(&mut self) -> &mut PollEvents
Returns a mutable reference to the events that were returned by the poll operation.