pub struct PollEvents(/* private fields */);Implementations
Sourceimpl PollEvents
impl PollEvents
Sourcepub const DATA_AVAILABLE: Self
pub const DATA_AVAILABLE: Self
Waiting for data to be available to read.
Sourcepub const DISCONNECTED: Self
pub const DISCONNECTED: Self
The given resource is disconnected, usually is returned and not awaited for. reads may still be possible if there is data available.
pub const fn contains(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
pub const fn is_empty(&self) -> bool
pub const fn union(&self, other: Self) -> Self
pub const fn intersection(&self, other: Self) -> Self
pub const fn difference(&self, other: Self) -> Self