pub struct LocalSocketAddr {
pub sin_name: [u8; 128],
/* private fields */
}Expand description
A local family socket address, converted from SocketAddr
Fields
sin_name: [u8; 128]Must be valid UTF-8, the actual length is provided to socket syscalls.
Implementations
Sourceimpl LocalSocketAddr
impl LocalSocketAddr
Sourcepub const fn new(name: [u8; 128]) -> Self
pub const fn new(name: [u8; 128]) -> Self
Creates a new abstract binding Addr from a given name bytes, name[..name_length] must be valid UTF8 where name_length is
This structures total length - size_of::<SocketAddr>()
The structures total length is passed to sockets syscalls.
Sourcepub fn new_abstract_from(name: &str) -> (Self, usize)
pub fn new_abstract_from(name: &str) -> (Self, usize)
Creates a new abstract binding Addr from a given name, name must be valid UTF8
returns the actual structure length.
Panicks if name.len() > MAX_NAME_LENGTH
pub const fn as_bytes(&self) -> &[u8]