pub struct SockMsgFlags(/* private fields */);Expand description
Flags for a message transmitted to and received from a socket.
Implementations
Sourceimpl SockMsgFlags
impl SockMsgFlags
pub const NONE: Self
Sourcepub const DONT_WAIT: Self
pub const DONT_WAIT: Self
Return an error if sending/receiving the message would block instead of blocking.
Sourcepub const PEEK: Self
pub const PEEK: Self
For a receive operation, only read the message without removing it from the queue, so another receive operation would read the same exact message.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true If self contains the flags other containsa
pub const fn from_bits_retaining(bits: u32) -> Self
pub const fn into_bits(self) -> u32